@@ -1,5 +1,6 @@
-from PyObjCTools.TestSupport import *
 import CoreText
+from PyObjCTools.TestSupport import TestCase, min_os_level
+import objc
 
 
 class TestCTFontManager(TestCase):
@@ -13,7 +14,7 @@ class TestCTFontManager(TestCase):
             CoreText.kCTFontManagerScopeUser, CoreText.kCTFontManagerScopePersistent
         )
 
-        self.assertIsInstance(CoreText.kCTFontManagerBundleIdentifier, unicode)
+        self.assertIsInstance(CoreText.kCTFontManagerBundleIdentifier, str)
 
         self.assertEqual(CoreText.kCTFontManagerAutoActivationDefault, 0)
         self.assertEqual(CoreText.kCTFontManagerAutoActivationDisabled, 1)
@@ -21,15 +22,21 @@ class TestCTFontManager(TestCase):
         self.assertEqual(CoreText.kCTFontManagerAutoActivationPromptUser, 3)
 
         self.assertIsInstance(
-            CoreText.kCTFontManagerRegisteredFontsChangedNotification, unicode
+            CoreText.kCTFontManagerRegisteredFontsChangedNotification, str
         )
 
     @min_os_level("10.6")
     def testFunctions10_6(self):
-        self.assertResultIsCFRetained(CoreText.CTFontManagerCopyAvailablePostScriptNames)
-        self.assertResultIsCFRetained(CoreText.CTFontManagerCopyAvailableFontFamilyNames)
+        self.assertResultIsCFRetained(
+            CoreText.CTFontManagerCopyAvailablePostScriptNames
+        )
+        self.assertResultIsCFRetained(
+            CoreText.CTFontManagerCopyAvailableFontFamilyNames
+        )
         self.assertResultIsCFRetained(CoreText.CTFontManagerCopyAvailableFontURLs)
-        self.assertResultIsCFRetained(CoreText.CTFontManagerCreateFontDescriptorsFromURL)
+        self.assertResultIsCFRetained(
+            CoreText.CTFontManagerCreateFontDescriptorsFromURL
+        )
 
         self.assertArgHasType(
             CoreText.CTFontManagerCompareFontFamilyNames, 0, b"^{__CFString=}"
@@ -59,17 +66,23 @@ class TestCTFontManager(TestCase):
 
     @min_os_level("10.7")
     def testFunctions10_7(self):
-        self.assertResultIsCFRetained(CoreText.CTFontManagerCreateFontDescriptorFromData)
+        self.assertResultIsCFRetained(
+            CoreText.CTFontManagerCreateFontDescriptorFromData
+        )
 
     @min_os_level("10.8")
     def testFunctions10_8(self):
-        self.assertResultIsCFRetained(CoreText.CTFontManagerCreateFontDescriptorFromData)
+        self.assertResultIsCFRetained(
+            CoreText.CTFontManagerCreateFontDescriptorFromData
+        )
         self.assertArgIsOut(CoreText.CTFontManagerRegisterGraphicsFont, 1)
         self.assertArgIsOut(CoreText.CTFontManagerUnregisterGraphicsFont, 1)
 
     @min_os_level("10.13")
     def testFunctions10_13(self):
-        self.assertResultIsCFRetained(CoreText.CTFontManagerCreateFontDescriptorsFromData)
+        self.assertResultIsCFRetained(
+            CoreText.CTFontManagerCreateFontDescriptorsFromData
+        )
 
     @min_os_level("10.15")
     def testFunctions10_15(self):
@@ -93,7 +106,3 @@ class TestCTFontManager(TestCase):
             2,
             objc._C_BOOL + objc._C_ID + objc._C_BOOL,
         )
-
-
-if __name__ == "__main__":
-    main()
